# cuzcatlan
> Historical note: Cuzcatlán is how the natives (the Pipil people) called what is now El Salvador. The Nahuatl etymology is such that the suffix "-tlan" is added to identify a place/location and the root of the word (which has found multiple spellings using roman characters, Cuzca, Cusca, and Kozcatl, to list a few) is used to describe "good things" it would sometimes mean literally diamonds, gold, or jade but in some contexts it would refer to how precious something was. Hence it is believed that the Pipil people would refer to their land as "The Place Where Good/Precious Things Are Found."

In this library, you can find many (hopefully good) functions intended to be a support library for GenePattern.
